@@ -60,6 +60,7 @@ func Test_processSPDXLicense(t *testing.T) {
 				"0bsd":                                   "0BSD",
 				"aal":                                    "AAL",
 				"abstyles":                               "Abstyles",
+				"adacore-doc":                            "AdaCore-doc",
 				"adobe-2006":                             "Adobe-2006",
 				"adobe-2006.0":                           "Adobe-2006",
 				"adobe-2006.0.0":                         "Adobe-2006",
@@ -145,6 +146,7 @@ func Test_processSPDXLicense(t *testing.T) {
 				"bahyph":                                 "Bahyph",
 				"barr":                                   "Barr",
 				"beerware":                               "Beerware",
+				"bitstream-charter":                      "Bitstream-Charter",
 				"bitstream-vera":                         "Bitstream-Vera",
 				"bittorrent-1":                           "BitTorrent-1.0",
 				"bittorrent-1.0":                         "BitTorrent-1.0",
@@ -156,6 +158,9 @@ func Test_processSPDXLicense(t *testing.T) {
 				"blueoak-1.0":                            "BlueOak-1.0.0",
 				"blueoak-1.0.0":                          "BlueOak-1.0.0",
 				"borceux":                                "Borceux",
+				"brian-gladman-3-clause":                 "Brian-Gladman-3-Clause",
+				"brian-gladman-3.0-clause":               "Brian-Gladman-3-Clause",
+				"brian-gladman-3.0.0-clause":             "Brian-Gladman-3-Clause",
 				"bsd-1-clause":                           "BSD-1-Clause",
 				"bsd-1.0-clause":                         "BSD-1-Clause",
 				"bsd-1.0.0-clause":                       "BSD-1-Clause",
@@ -213,6 +218,14 @@ func Test_processSPDXLicense(t *testing.T) {
 				"bsd-4.0.0-clause":                         "BSD-4-Clause",
 				"bsd-4.0.0-clause-shortened":               "BSD-4-Clause-Shortened",
 				"bsd-4.0.0-clause-uc":                      "BSD-4-Clause-UC",
+				"bsd-4.3.0reno":                            "BSD-4.3RENO",
+				"bsd-4.3.0tahoe":                           "BSD-4.3TAHOE",
+				"bsd-4.3reno":                              "BSD-4.3RENO",
+				"bsd-4.3tahoe":                             "BSD-4.3TAHOE",
+				"bsd-4reno":                                "BSD-4.3RENO",
+				"bsd-4tahoe":                               "BSD-4.3TAHOE",
+				"bsd-advertising-acknowledgement":          "BSD-Advertising-Acknowledgement",
+				"bsd-attribution-hpnd-disclaimer":          "BSD-Attribution-HPND-disclaimer",
 				"bsd-protection":                           "BSD-Protection",
 				"bsd-source-code":                          "BSD-Source-Code",
 				"bsl-1":                                    "BSL-1.0",
@@ -311,12 +324,15 @@ func Test_processSPDXLicense(t *testing.T) {
 				"cc-by-nc-sa-1.0":                          "CC-BY-NC-SA-1.0",
 				"cc-by-nc-sa-1.0.0":                        "CC-BY-NC-SA-1.0",
 				"cc-by-nc-sa-2":                            "CC-BY-NC-SA-2.0",
+				"cc-by-nc-sa-2-de":                         "CC-BY-NC-SA-2.0-DE",
 				"cc-by-nc-sa-2-fr":                         "CC-BY-NC-SA-2.0-FR",
 				"cc-by-nc-sa-2-uk":                         "CC-BY-NC-SA-2.0-UK",
 				"cc-by-nc-sa-2.0":                          "CC-BY-NC-SA-2.0",
+				"cc-by-nc-sa-2.0-de":                       "CC-BY-NC-SA-2.0-DE",
 				"cc-by-nc-sa-2.0-fr":                       "CC-BY-NC-SA-2.0-FR",
 				"cc-by-nc-sa-2.0-uk":                       "CC-BY-NC-SA-2.0-UK",
 				"cc-by-nc-sa-2.0.0":                        "CC-BY-NC-SA-2.0",
+				"cc-by-nc-sa-2.0.0-de":                     "CC-BY-NC-SA-2.0-DE",
 				"cc-by-nc-sa-2.0.0-fr":                     "CC-BY-NC-SA-2.0-FR",
 				"cc-by-nc-sa-2.0.0-uk":                     "CC-BY-NC-SA-2.0-UK",
 				"cc-by-nc-sa-2.5":                          "CC-BY-NC-SA-2.5",
@@ -423,8 +439,11 @@ func Test_processSPDXLicense(t *testing.T) {
 				"cern-ohl-w-2":                             "CERN-OHL-W-2.0",
 				"cern-ohl-w-2.0":                           "CERN-OHL-W-2.0",
 				"cern-ohl-w-2.0.0":                         "CERN-OHL-W-2.0",
+				"cfitsio":                                  "CFITSIO",
 				"checkmk":                                  "checkmk",
 				"clartistic":                               "ClArtistic",
+				"clips":                                    "Clips",
+				"cmu-mach":                                 "CMU-Mach",
 				"cnri-jython":                              "CNRI-Jython",
 				"cnri-python":                              "CNRI-Python",
 				"cnri-python-gpl-compatible":               "CNRI-Python-GPL-Compatible",
@@ -440,6 +459,7 @@ func Test_processSPDXLicense(t *testing.T) {
 				"copyleft-next-0.3":                        "copyleft-next-0.3.0",
 				"copyleft-next-0.3.0":                      "copyleft-next-0.3.0",
 				"copyleft-next-0.3.1":                      "copyleft-next-0.3.1",
+				"cornell-lossless-jpeg":                    "Cornell-Lossless-JPEG",
 				"cpal-1":                                   "CPAL-1.0",
 				"cpal-1.0":                                 "CPAL-1.0",
 				"cpal-1.0.0":                               "CPAL-1.0",
@@ -637,6 +657,7 @@ func Test_processSPDXLicense(t *testing.T) {
 				"gpl-3.0.0-or-later":                       "GPL-3.0-or-later",
 				"gpl-3.0.0-with-autoconf-exception":        "GPL-3.0-with-autoconf-exception",
 				"gpl-3.0.0-with-gcc-exception":             "GPL-3.0-with-GCC-exception",
+				"graphics-gems":                            "Graphics-Gems",
 				"gsoap-1.3.0b":                             "gSOAP-1.3b",
 				"gsoap-1.3b":                               "gSOAP-1.3b",
 				"gsoap-1b":                                 "gSOAP-1.3b",
@@ -644,12 +665,20 @@ func Test_processSPDXLicense(t *testing.T) {
 				"hippocratic-2":                            "Hippocratic-2.1",
 				"hippocratic-2.1":                          "Hippocratic-2.1",
 				"hippocratic-2.1.0":                        "Hippocratic-2.1",
+				"hp-1986":                                  "HP-1986",
+				"hp-1986.0":                                "HP-1986",
+				"hp-1986.0.0":                              "HP-1986",
 				"hpnd":                                     "HPND",
+				"hpnd-export-us":                           "HPND-export-US",
+				"hpnd-markus-kuhn":                         "HPND-Markus-Kuhn",
 				"hpnd-sell-variant":                        "HPND-sell-variant",
+				"hpnd-sell-variant-mit-disclaimer":         "HPND-sell-variant-MIT-disclaimer",
 				"htmltidy":                                 "HTMLTIDY",
 				"ibm-pibs":                                 "IBM-pibs",
 				"icu":                                      "ICU",
+				"iec-code-components-eula":                 "IEC-Code-Components-EULA",
 				"ijg":                                      "IJG",
+				"ijg-short":                                "IJG-short",
 				"imagemagick":                              "ImageMagick",
 				"imatix":                                   "iMatix",
 				"imlib2":                                   "Imlib2",
@@ -668,8 +697,10 @@ func Test_processSPDXLicense(t *testing.T) {
 				"jasper-2":                                 "JasPer-2.0",
 				"jasper-2.0":                               "JasPer-2.0",
 				"jasper-2.0.0":                             "JasPer-2.0",
+				"jpl-image":                                "JPL-image",
 				"jpnic":                                    "JPNIC",
 				"json":                                     "JSON",
+				"kazlib":                                   "Kazlib",
 				"knuth-ctan":                               "Knuth-CTAN",
 				"lal-1":                                    "LAL-1.2",
 				"lal-1.2":                                  "LAL-1.2",
@@ -731,6 +762,7 @@ func Test_processSPDXLicense(t *testing.T) {
 				"liliq-rplus-1.1.0":                        "LiLiQ-Rplus-1.1",
 				"linux-man-pages-copyleft":                 "Linux-man-pages-copyleft",
 				"linux-openib":                             "Linux-OpenIB",
+				"loop":                                     "LOOP",
 				"lpl-1":                                    "LPL-1.0",
 				"lpl-1.0":                                  "LPL-1.0",
 				"lpl-1.0.0":                                "LPL-1.0",
@@ -756,6 +788,7 @@ func Test_processSPDXLicense(t *testing.T) {
 				"lzma-sdk-9.22":                            "LZMA-SDK-9.22",
 				"lzma-sdk-9.22.0":                          "LZMA-SDK-9.22",
 				"makeindex":                                "MakeIndex",
+				"martin-birgmeier":                         "Martin-Birgmeier",
 				"minpack":                                  "Minpack",
 				"miros":                                    "MirOS",
 				"mit":                                      "MIT",
@@ -766,6 +799,7 @@ func Test_processSPDXLicense(t *testing.T) {
 				"mit-feh":                                  "MIT-feh",
 				"mit-modern-variant":                       "MIT-Modern-Variant",
 				"mit-open-group":                           "MIT-open-group",
+				"mit-wu":                                   "MIT-Wu",
 				"mitnfa":                                   "MITNFA",
 				"motosoto":                                 "Motosoto",
 				"mpi-permissive":                           "mpi-permissive",
@@ -852,6 +886,7 @@ func Test_processSPDXLicense(t *testing.T) {
 				"odc-by-1":                                 "ODC-By-1.0",
 				"odc-by-1.0":                               "ODC-By-1.0",
 				"odc-by-1.0.0":                             "ODC-By-1.0",
+				"offis":                                    "OFFIS",
 				"ofl-1":                                    "OFL-1.0",
 				"ofl-1-no-rfn":                             "OFL-1.0-no-RFN",
 				"ofl-1-rfn":                                "OFL-1.0-RFN",
@@ -918,6 +953,9 @@ func Test_processSPDXLicense(t *testing.T) {
 				"oldap-2.8":                                "OLDAP-2.8",
 				"oldap-2.8.0":                              "OLDAP-2.8",
 				"oml":                                      "OML",
+				"openpbs-2":                                "OpenPBS-2.3",
+				"openpbs-2.3":                              "OpenPBS-2.3",
+				"openpbs-2.3.0":                            "OpenPBS-2.3",
 				"openssl":                                  "OpenSSL",
 				"opl-1":                                    "OPL-1.0",
 				"opl-1.0":                                  "OPL-1.0",
@@ -974,8 +1012,11 @@ func Test_processSPDXLicense(t *testing.T) {
 				"python-2.0.1":                             "Python-2.0.1",
 				"qhull":                                    "Qhull",
 				"qpl-1":                                    "QPL-1.0",
+				"qpl-1-inria-2004":                         "QPL-1.0-INRIA-2004",
 				"qpl-1.0":                                  "QPL-1.0",
+				"qpl-1.0-inria-2004":                       "QPL-1.0-INRIA-2004",
 				"qpl-1.0.0":                                "QPL-1.0",
+				"qpl-1.0.0-inria-2004":                     "QPL-1.0-INRIA-2004",
 				"rdisc":                                    "Rdisc",
 				"rhecos-1":                                 "RHeCos-1.1",
 				"rhecos-1.1":                               "RHeCos-1.1",
@@ -1022,6 +1063,7 @@ func Test_processSPDXLicense(t *testing.T) {
 				"smlnj":                                    "SMLNJ",
 				"smppl":                                    "SMPPL",
 				"snia":                                     "SNIA",
+				"snprintf":                                 "snprintf",
 				"spencer-86":                               "Spencer-86",
 				"spencer-86.0":                             "Spencer-86",
 				"spencer-86.0.0":                           "Spencer-86",
@@ -1043,7 +1085,9 @@ func Test_processSPDXLicense(t *testing.T) {
 				"sugarcrm-1":                               "SugarCRM-1.1.3",
 				"sugarcrm-1.1":                             "SugarCRM-1.1.3",
 				"sugarcrm-1.1.3":                           "SugarCRM-1.1.3",
+				"sunpro":                                   "SunPro",
 				"swl":                                      "SWL",
+				"symlinks":                                 "Symlinks",
 				"tapr-ohl-1":                               "TAPR-OHL-1.0",
 				"tapr-ohl-1.0":                             "TAPR-OHL-1.0",
 				"tapr-ohl-1.0.0":                           "TAPR-OHL-1.0",
@@ -1054,12 +1098,18 @@ func Test_processSPDXLicense(t *testing.T) {
 				"torque-1.1":                               "TORQUE-1.1",
 				"torque-1.1.0":                             "TORQUE-1.1",
 				"tosl":                                     "TOSL",
+				"tpdl":                                     "TPDL",
+				"tpl-1":                                    "TPL-1.0",
+				"tpl-1.0":                                  "TPL-1.0",
+				"tpl-1.0.0":                                "TPL-1.0",
+				"ttwl":                                     "TTWL",
 				"tu-berlin-1":                              "TU-Berlin-1.0",
 				"tu-berlin-1.0":                            "TU-Berlin-1.0",
 				"tu-berlin-1.0.0":                          "TU-Berlin-1.0",
 				"tu-berlin-2":                              "TU-Berlin-2.0",
 				"tu-berlin-2.0":                            "TU-Berlin-2.0",
 				"tu-berlin-2.0.0":                          "TU-Berlin-2.0",
+				"ucar":                                     "UCAR",
 				"ucl-1":                                    "UCL-1.0",
 				"ucl-1.0":                                  "UCL-1.0",
 				"ucl-1.0.0":                                "UCL-1.0",
@@ -1086,6 +1136,7 @@ func Test_processSPDXLicense(t *testing.T) {
 				"w3c-20150513":                             "W3C-20150513",
 				"w3c-20150513.0":                           "W3C-20150513",
 				"w3c-20150513.0.0":                         "W3C-20150513",
+				"w3m":                                      "w3m",
 				"watcom-1":                                 "Watcom-1.0",
 				"watcom-1.0":                               "Watcom-1.0",
 				"watcom-1.0.0":                             "Watcom-1.0",
@@ -1099,6 +1150,7 @@ func Test_processSPDXLicense(t *testing.T) {
 				"xfree86-1.1":                              "XFree86-1.1",
 				"xfree86-1.1.0":                            "XFree86-1.1",
 				"xinetd":                                   "xinetd",
+				"xlock":                                    "xlock",
 				"xnet":                                     "Xnet",
 				"xpp":                                      "xpp",
 				"xskat":                                    "XSkat",
