@@ -4,11 +4,7 @@ import (
 	"github.com/anchore/syft/syft/pkg/cataloger/generic"
 )
 
-const (
-	eggMetadataGlob     = "**/*egg-info/PKG-INFO"
-	eggFileMetadataGlob = "**/*.egg-info"
-	wheelMetadataGlob   = "**/*dist-info/METADATA"
-)
+const eggInfoGlob = "**/*.egg-info"
 
 // NewPythonIndexCataloger returns a new cataloger for python packages referenced from poetry lock files, requirements.txt files, and setup.py files.
 func NewPythonIndexCataloger() *generic.Cataloger {
@@ -22,5 +18,5 @@ func NewPythonIndexCataloger() *generic.Cataloger {
 // NewPythonPackageCataloger returns a new cataloger for python packages within egg or wheel installation directories.
 func NewPythonPackageCataloger() *generic.Cataloger {
 	return generic.NewCataloger("python-package-cataloger").
-		WithParserByGlobs(parseWheelOrEgg, eggMetadataGlob, eggFileMetadataGlob, wheelMetadataGlob)
+		WithParserByGlobs(parseWheelOrEgg, eggInfoGlob, "**/*dist-info/METADATA", "**/*egg-info/PKG-INFO")
 }
